import type { Ref } from 'vue';
import type { Direction } from '../shared/types';
import type { PrimitiveProps } from '../Primitive';
export type AcceptableValue = string | number | boolean | Record<string, any>;
type ArrayOrWrapped<T> = T extends any[] ? T : Array<T>;
type ComboboxRootContext<T> = {
    modelValue: Ref<T | Array<T>>;
    onValueChange: (val: T) => void;
    searchTerm: Ref<string>;
    multiple: Ref<boolean>;
    disabled: Ref<boolean>;
    open: Ref<boolean>;
    onOpenChange: (value: boolean) => void;
    isUserInputted: Ref<boolean>;
    filteredOptions: Ref<Array<T>>;
    contentId: string;
    contentElement: Ref<HTMLElement | undefined>;
    onContentElementChange: (el: HTMLElement) => void;
    inputElement: Ref<HTMLInputElement | undefined>;
    onInputElementChange: (el: HTMLInputElement) => void;
    onInputNavigation: (dir: 'up' | 'down' | 'home' | 'end') => void;
    onInputEnter: () => void;
    selectedValue: Ref<T | undefined>;
    onSelectedValueChange: (val: T) => void;
    parentElement: Ref<HTMLElement | undefined>;
};
export declare const injectComboboxRootContext: <T extends ComboboxRootContext<AcceptableValue> | null | undefined = ComboboxRootContext<AcceptableValue>>(fallback?: T | undefined) => T extends null ? ComboboxRootContext<AcceptableValue> | null : ComboboxRootContext<AcceptableValue>, provideComboboxRootContext: (contextValue: ComboboxRootContext<AcceptableValue>) => ComboboxRootContext<AcceptableValue>;
export type ComboboxRootEmits<T = AcceptableValue> = {
    /** Event handler called when the value changes. */
    'update:modelValue': [value: T];
    /** Event handler called when the open state of the combobox changes. */
    'update:open': [value: boolean];
    /** Event handler called when the searchTerm of the combobox changes. */
    'update:searchTerm': [value: string];
};
export interface ComboboxRootProps<T = AcceptableValue> extends PrimitiveProps {
    /** The controlled value of the Combobox. Can be binded-with with `v-model`. */
    modelValue?: T | Array<T>;
    /** The value of the combobox when initially rendered. Use when you do not need to control the state of the Combobox */
    defaultValue?: T | Array<T>;
    /** The controlled open state of the Combobox. Can be binded-with with `v-model:open`. */
    open?: boolean;
    /** The open state of the combobox when it is initially rendered. <br> Use when you do not need to control its open state. */
    defaultOpen?: boolean;
    /** The controlled search term of the Combobox. Can be binded-with with v-model:searchTerm. */
    searchTerm?: string;
    /** Whether multiple options can be selected or not. */
    multiple?: boolean;
    /** When `true`, prevents the user from interacting with Combobox */
    disabled?: boolean;
    /** The name of the Combobox. Submitted with its owning form as part of a name/value pair. */
    name?: string;
    /** The reading direction of the combobox when applicable. <br> If omitted, inherits globally from `DirectionProvider` or assumes LTR (left-to-right) reading mode. */
    dir?: Direction;
    /** The custom filter function for filtering `ComboboxItem`. */
    filterFunction?: (val: ArrayOrWrapped<T>, term: string) => ArrayOrWrapped<T>;
    /** The display value of input for selected item. Does not work with `multiple`. */
    displayValue?: (val: T) => string;
}
declare const _default: <T extends AcceptableValue = AcceptableValue>(__VLS_props: {
    defaultValue?: T | T[] | undefined;
    dir?: Direction | undefined;
    disabled?: boolean | undefined;
    multiple?: boolean | undefined;
    name?: string | undefined;
    asChild?: boolean | undefined;
    as?: import('../Primitive').AsTag | import("vue").Component | undefined;
    defaultOpen?: boolean | undefined;
    open?: boolean | undefined;
    "onUpdate:open"?: ((value: boolean) => any) | undefined;
    modelValue?: T | T[] | undefined;
    "onUpdate:modelValue"?: ((value: T) => any) | undefined;
    searchTerm?: string | undefined;
    filterFunction?: ((val: ArrayOrWrapped<T>, term: string) => ArrayOrWrapped<T>) | undefined;
    displayValue?: ((val: T) => string) | undefined;
    "onUpdate:searchTerm"?: ((value: string) => any) | undefined;
} & import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, __VLS_ctx?: {
    slots: Readonly<{
        default(props: {
            /** Current open state */
            open: boolean;
            /** Current active value */
            modelValue: T | T[];
        }): any;
    }> & {
        default(props: {
            /** Current open state */
            open: boolean;
            /** Current active value */
            modelValue: T | T[];
        }): any;
    };
    attrs: any;
    emit: ((evt: "update:open", value: boolean) => void) & ((evt: "update:modelValue", value: T) => void) & ((evt: "update:searchTerm", value: string) => void);
} | undefined, __VLS_expose?: ((exposed: import('vue').ShallowUnwrapRef<{}>) => void) | undefined, __VLS_setup?: Promise<{
    props: {
        defaultValue?: T | T[] | undefined;
        dir?: Direction | undefined;
        disabled?: boolean | undefined;
        multiple?: boolean | undefined;
        name?: string | undefined;
        asChild?: boolean | undefined;
        as?: import('../Primitive').AsTag | import("vue").Component | undefined;
        defaultOpen?: boolean | undefined;
        open?: boolean | undefined;
        "onUpdate:open"?: ((value: boolean) => any) | undefined;
        modelValue?: T | T[] | undefined;
        "onUpdate:modelValue"?: ((value: T) => any) | undefined;
        searchTerm?: string | undefined;
        filterFunction?: ((val: ArrayOrWrapped<T>, term: string) => ArrayOrWrapped<T>) | undefined;
        displayValue?: ((val: T) => string) | undefined;
        "onUpdate:searchTerm"?: ((value: string) => any) | undefined;
    } & import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps;
    expose(exposed: import('vue').ShallowUnwrapRef<{}>): void;
    attrs: any;
    slots: Readonly<{
        default(props: {
            /** Current open state */
            open: boolean;
            /** Current active value */
            modelValue: T | T[];
        }): any;
    }> & {
        default(props: {
            /** Current open state */
            open: boolean;
            /** Current active value */
            modelValue: T | T[];
        }): any;
    };
    emit: ((evt: "update:open", value: boolean) => void) & ((evt: "update:modelValue", value: T) => void) & ((evt: "update:searchTerm", value: string) => void);
}>) => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
    [key: string]: any;
}> & {
    __ctx?: {
        props: {
            defaultValue?: T | T[] | undefined;
            dir?: Direction | undefined;
            disabled?: boolean | undefined;
            multiple?: boolean | undefined;
            name?: string | undefined;
            asChild?: boolean | undefined;
            as?: import('../Primitive').AsTag | import("vue").Component | undefined;
            defaultOpen?: boolean | undefined;
            open?: boolean | undefined;
            "onUpdate:open"?: ((value: boolean) => any) | undefined;
            modelValue?: T | T[] | undefined;
            "onUpdate:modelValue"?: ((value: T) => any) | undefined;
            searchTerm?: string | undefined;
            filterFunction?: ((val: ArrayOrWrapped<T>, term: string) => ArrayOrWrapped<T>) | undefined;
            displayValue?: ((val: T) => string) | undefined;
            "onUpdate:searchTerm"?: ((value: string) => any) | undefined;
        } & import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps;
        expose(exposed: import('vue').ShallowUnwrapRef<{}>): void;
        attrs: any;
        slots: Readonly<{
            default(props: {
                /** Current open state */
                open: boolean;
                /** Current active value */
                modelValue: T | T[];
            }): any;
        }> & {
            default(props: {
                /** Current open state */
                open: boolean;
                /** Current active value */
                modelValue: T | T[];
            }): any;
        };
        emit: ((evt: "update:open", value: boolean) => void) & ((evt: "update:modelValue", value: T) => void) & ((evt: "update:searchTerm", value: string) => void);
    } | undefined;
};
export default _default;
type __VLS_Prettify<T> = {
    [K in keyof T]: T[K];
} & {};
